==> localnews-msg-common-1.3.1-20190117.153043-1-sources.jar: com/bxm/localnews/mq/common/model/dto/PushPayloadInfo.java <==
package com.bxm.localnews.mq.common.model.dto;

import com.alibaba.fastjson.JSONObject;
import com.bxm.localnews.mq.common.constant.PushMessageEnum;
import com.bxm.newidea.component.vo.BaseBean;
import com.google.common.collect.Maps;

import java.util.Map;

/**
 * 消息个推主体信息
 * @author liujia 2018/8/14 20:21
 */
public class PushPayloadInfo extends BaseBean {

    /**
     * 当前推送消息的ID
     */
    private Long msgId;

    /**
     * 推送的消息类型{@link PushMessageEnum}
     */
    private int type;

    /**
     * 创建消息的时间(时间戳)
     */
    private Long createTime;

    /**
     * 通知标题,安卓特有
     */
    private String title;

    /**
     * 通知内容,安卓特有
     */
    private String content;

    /**
     * 通知铃声,安卓特有
     */
    private String sound;

    /**
     * 额外参数
     */
    private Map<String, Object> extend;

    public static PushPayloadInfo build() {
        return new PushPayloadInfo().setCreateTime(System.currentTimeMillis());
    }

    public static PushPayloadInfo build(PushMessageEnum type) {
        PushPayloadInfo info = new PushPayloadInfo();
        info.setType(type.getType());
        info.setCreateTime(System.currentTimeMillis());
        return info;
    }

    public PushPayloadInfo addExtend(String key, Object value) {
        if (this.extend == null) {
            this.extend = Maps.newHashMap();
        }

        this.extend.put(key, value);
        return this;
    }

    public Long getMsgId() {
        return msgId;
    }

    public void setMsgId(Long msgId) {
        this.msgId = msgId;
    }

    public String toJsonString() {
        return JSONObject.toJSONString(this);
    }

    public Map<String, Object> getExtend() {
        return this.extend;
    }

    public void setExtend(Map<String, Object> extend) {
        this.extend = extend;
    }

    public int getType() {
        return this.type;
    }

    public PushPayloadInfo setType(int type) {
        this.type = type;
        return this;
    }

    public Long getCreateTime() {
        return this.createTime;
    }

    public PushPayloadInfo setCreateTime(Long createTime) {
        this.createTime = createTime;
        return this;
    }

    public String getTitle() {
        return this.title;
    }

    public PushPayloadInfo setTitle(String title) {
        this.title = title;
        return this;
    }

    public String getContent() {
        return this.content;
    }

    public PushPayloadInfo setContent(String content) {
        this.content = content;
        return this;
    }

    public String getSound() {
        return this.sound;
    }

    public PushPayloadInfo setSound(String sound) {
        this.sound = sound;
        return this;
    }

}

==> localnews-msg-common-1.3.3-20190221.093037-3-sources.jar: com/bxm/localnews/mq/common/model/dto/PushPayloadInfo.java <==
package com.bxm.localnews.mq.common.model.dto;

import java.util.Map;

import com.alibaba.fastjson.JSONObject;
import com.bxm.localnews.mq.common.constant.PushMessageEnum;
import com.bxm.newidea.component.vo.BaseBean;
import com.google.common.collect.Maps;

/**
 * 消息个推主体信息
 *
 * @author liujia 2018/8/14 20:21
 */
public class PushPayloadInfo extends BaseBean {

    /**
     * 当前推送消息的ID
     */
    private Long msgId;

    /**
     * 推送的消息类型{@link PushMessageEnum}
     */
    private int type = 0;

    /**
     * 创建消息的时间(时间戳)
     */
    private Long createTime;

    /**
     * 通知标题,安卓特有
     */
    private String title;

    /**
     * 通知内容,安卓特有
     */
    private String content;

    /**
     * 通知铃声,安卓特有
     */
    private String sound;

    /**
     * 额外参数
     */
    private Map<String, Object> extend = Maps.newHashMap();

    public static PushPayloadInfo build() {
        return new PushPayloadInfo().setCreateTime(System.currentTimeMillis());
    }

    public static PushPayloadInfo build(PushMessageEnum type) {
        PushPayloadInfo info = new PushPayloadInfo();
        info.setType(type.getType());
        info.setCreateTime(System.currentTimeMillis());
        return info;
    }

    public PushPayloadInfo addExtend(String key, Object value) {
        if (this.extend == null) {
            this.extend = Maps.newHashMap();
        }

        this.extend.put(key, value);
        return this;
    }

    public Long getMsgId() {
        return msgId;
    }

    public void setMsgId(Long msgId) {
        this.msgId = msgId;
    }

    public String toJsonString() {
        return JSONObject.toJSONString(this);
    }

    public Map<String, Object> getExtend() {
        return this.extend;
    }

    public void setExtend(Map<String, Object> extend) {
        this.extend = extend;
    }

    public int getType() {
        return this.type;
    }

    public PushPayloadInfo setType(int type) {
        this.type = type;
        return this;
    }

    public Long getCreateTime() {
        return this.createTime;
    }

    public PushPayloadInfo setCreateTime(Long createTime) {
        this.createTime = createTime;
        return this;
    }

    public String getTitle() {
        return this.title;
    }

    public PushPayloadInfo setTitle(String title) {
        this.title = title;
        return this;
    }

    public String getContent() {
        return this.content;
    }

    public PushPayloadInfo setContent(String content) {
        this.content = content;
        return this;
    }

    public String getSound() {
        return this.sound;
    }

    public PushPayloadInfo setSound(String sound) {
        this.sound = sound;
        return this;
    }

}
